%bcond_without test
%bcond_with doc

%define module	pikepdf

Name:		python-%{module}
Version:	9.3.0
Release:	%mkrel 1
Summary:	Read and write PDFs with Python, powered by qpdf
Group:		Development/Python
License:	MPLv2.0
URL:		https://github.com/pikepdf/pikepdf
Source0:	https://pypi.io/packages/source/p/%{module}/%{module}-%{version}.tar.gz

BuildRequires:	gcc-c++
BuildRequires:	jbig2dec
BuildRequires:	pyproject-rpm-macros
BuildRequires:	pkgconfig(libqpdf) >= 11.5.0
BuildRequires:	pkgconfig(python3)
BuildRequires:	pybind11-devel
BuildRequires:	python3dist(lxml)
BuildRequires:	python3dist(pybind11)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(setuptools-scm)
BuildRequires:	python3dist(setuptools-scm[toml])
BuildRequires:	python3dist(setuptools-scm-git-archive)
# Tests:
%if %{with test}
BuildRequires:	poppler
BuildRequires:	python3dist(deprecation)
BuildRequires:	python3dist(attrs)
BuildRequires:	python3dist(hypothesis)
BuildRequires:	python3dist(pillow)
BuildRequires:	python3dist(psutil)
BuildRequires:	python3dist(pytest)
BuildRequires:	python3dist(pytest-runner)
BuildRequires:	python3dist(pytest-timeout)
BuildRequires:	python3dist(pytest-xdist)
BuildRequires:	python3dist(python-xmp-toolkit)
%endif

%description
pikepdf is a Python library for reading and writing PDF files. pikepdf is
based on QPDF, a powerful PDF manipulation and repair library.


%package -n	python3-%{module}
Summary:	Read and write PDFs with Python3, powered by qpdf
Group:		Development/Python
%{?python_provide:%python_provide python3-%{module}}

%description -n	python3-%{module}
pikepdf is a Python 3 library for reading and writing PDF files. pikepdf
is based on QPDF, a powerful PDF manipulation and repair library.


%if %{with doc}
%package -n	python-%{module}-doc
Summary:	pikepdf documentation
Group:		Documentation
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(sphinx-rtd-theme)
BuildRequires:	python3dist(sphinx-issues)
BuildRequires:	python3dist(sphinx-design)
BuildRequires:	python3dist(gitpython)
BuildRequires:	python3dist(pygithub)
BuildRequires:	python3dist(requests)
BuildRequires:	python3dist(pillow)
BuildRequires:	python3dist(matplotlib)
BuildRequires:	python3dist(pip)
BuildRequires:	python-wheel
BuildRequires:	ipython

%description -n	python-%{module}-doc
Documentation for pikepdf.
%endif

%prep
%autosetup -n %{module}-%{version} -p1

# Drop coverage requirements
sed -i -e '/coverage/d' -e '/pytest-cov/d' setup.cfg

# Remove bundled egg-info
rm -rf src/%{module}.egg-info

# We don't build docs against the installed version, so force the version.
sed -i -e "s/release = .\+/release = '%{version}'/g" docs/conf.py

%build
%pyproject_wheel

%if %{with doc}
# generate html docs
# installing our module, to use it for docs generation. Needed for access to metadata.
# this is not working yet, importlib.metadata.PackageNotFoundError: No package metadata was found for pikepdf
pushd docs
mkdir build
PYTHONPATH=$(ls -d ${PWD}/build) sphinx-build-3  -D language=en . ../html
popd
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%pyproject_install

# ensure .so modules are executable for proper -debuginfo extraction
chmod a+rx %{buildroot}%{python3_sitearch}/%{module}/*.so

%check
%if %{with test}
# Some of these tests actually fails: tests/{test_pdfa.py,test_foreign.py,test_outlines.py,test_pdf.py,test_private_pdfs.py}
# Skip for now, but keep track in building logs. To review.
%{pytest} -ra || :
%endif

%files -n python3-%{module}
%license LICENSE.txt
%doc README.md
%{python3_sitearch}/%{module}/
%{python3_sitearch}/%{module}-%{version}.dist-info

%if %{with doc}
%files -n python-%{module}-doc
%doc html
%license LICENSE.txt
%endif


%changelog
* Fri Oct 04 2024 daviddavid <daviddavid> 9.3.0-1.mga10
+ Revision: 2103080
- new version: 9.3.0

* Sat Sep 14 2024 daviddavid <daviddavid> 9.2.1-1.mga10
+ Revision: 2095979
- new version: 9.2.1

* Sun Aug 25 2024 daviddavid <daviddavid> 9.2.0-1.mga10
+ Revision: 2091162
- new version: 9.2.0

* Wed Aug 21 2024 daviddavid <daviddavid> 9.1.1-1.mga10
+ Revision: 2087255
- new version: 9.1.1

* Sat Aug 03 2024 daviddavid <daviddavid> 9.1.0-1.mga10
+ Revision: 2083500
- new version: 9.1.0

* Wed Jun 05 2024 daviddavid <daviddavid> 9.0.0-1.mga10
+ Revision: 2070113
- new version: 9.0.0

* Sat Apr 20 2024 daviddavid <daviddavid> 8.15.1-1.mga10
+ Revision: 2060154
- new version: 8.15.1

* Sun Feb 18 2024 daviddavid <daviddavid> 8.13.0-1.mga10
+ Revision: 2042323
- new version: 8.13.0

* Sat Jan 20 2024 daviddavid <daviddavid> 8.11.2-1.mga10
+ Revision: 2032419
- new version: 8.11.2

* Wed Dec 27 2023 daviddavid <daviddavid> 8.10.1-1.mga10
+ Revision: 2022035
- new version: 8.10.1

* Sat Dec 09 2023 daviddavid <daviddavid> 8.8.0-2.mga10
+ Revision: 2016179
- rebuild for py3.12

* Mon Dec 04 2023 daviddavid <daviddavid> 8.8.0-1.mga10
+ Revision: 2013095
- new version: 8.8.0

* Fri Nov 24 2023 daviddavid <daviddavid> 8.7.1-1.mga10
+ Revision: 2009439
- new version: 8.7.1

* Sun Nov 05 2023 daviddavid <daviddavid> 8.6.0-1.mga10
+ Revision: 2004570
- new version: 8.6.0

* Mon Oct 30 2023 daviddavid <daviddavid> 8.5.3-1.mga10
+ Revision: 2002846
- new version: 8.5.3

* Wed Oct 11 2023 daviddavid <daviddavid> 8.5.0-1.mga10
+ Revision: 1994648
- new version: 8.5.0

* Wed Sep 13 2023 daviddavid <daviddavid> 8.4.1-1.mga10
+ Revision: 1986386
- new version: 8.4.1

* Wed Aug 30 2023 daviddavid <daviddavid> 8.4.0-1.mga10
+ Revision: 1981869
- new version: 8.4.0

* Thu Jan 26 2023 daviddavid <daviddavid> 6.2.9-1.mga9
+ Revision: 1936216
- new version: 6.2.9

* Sun Jan 01 2023 daviddavid <daviddavid> 6.2.7-1.mga9
+ Revision: 1928673
- new version: 6.2.7

* Mon Dec 19 2022 daviddavid <daviddavid> 6.2.6-1.mga9
+ Revision: 1925317
- new version: 6.2.6

* Sat Dec 17 2022 daviddavid <daviddavid> 6.2.5-1.mga9
+ Revision: 1923880
- new version: 6.2.5

* Tue Nov 22 2022 daviddavid <daviddavid> 6.2.4-1.mga9
+ Revision: 1910120
- new version: 6.2.4

* Wed Nov 09 2022 daviddavid <daviddavid> 6.2.1-1.mga9
+ Revision: 1904906
- new version: 6.2.1

* Mon Oct 17 2022 ghibo <ghibo> 6.2.0-1.mga9
+ Revision: 1897328
- Update to release 6.2.0 (because newer qpdf 11.1 requires a newer python-pikepdf).
- Add jbig2dec to BuildRequires for tests.
- Drop coverage requirements (merged from FC).

* Mon Oct 10 2022 papoteur <papoteur> 5.6.1-2.mga9
+ Revision: 1896172
- Relax requirements in Buildrequires

* Tue Sep 06 2022 papoteur <papoteur> 5.6.1-1.mga9
+ Revision: 1884509
- new 5.6.1

* Fri Aug 26 2022 papoteur <papoteur> 5.5.0-1.mga9
+ Revision: 1880456
- new 5.5.0
  build without doc
- new 5.1.5
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Jun 04 2021 daviddavid <daviddavid> 2.12.1-1.mga9
+ Revision: 1729601
- new version: 2.12.1

* Thu May 13 2021 daviddavid <daviddavid> 2.12.0-1.mga9
+ Revision: 1722694
- new version: 2.12.0

* Fri Apr 30 2021 daviddavid <daviddavid> 2.11.4-1.mga9
+ Revision: 1720628
- new version: 2.11.4

* Fri Apr 30 2021 daviddavid <daviddavid> 2.11.3-1.mga9
+ Revision: 1720489
- new version: 2.11.3

* Fri Apr 23 2021 daviddavid <daviddavid> 2.11.2-1.mga9
+ Revision: 1718151
- new version: 2.11.2

* Sun Apr 18 2021 daviddavid <daviddavid> 2.11.1-1.mga9
+ Revision: 1716456
- new version: 2.11.1

* Mon Apr 12 2021 daviddavid <daviddavid> 2.11.0-1.mga9
+ Revision: 1714811
- new version: 2.11.0

* Tue Apr 06 2021 daviddavid <daviddavid> 2.10.0-1.mga9
+ Revision: 1713801
- new version: 2.10.0

* Fri Mar 26 2021 daviddavid <daviddavid> 2.9.2-1.mga9
+ Revision: 1710417
- new version: 2.9.2

* Mon Mar 22 2021 daviddavid <daviddavid> 2.9.1-1.mga9
+ Revision: 1707660
- new version: 2.9.1

* Sat Mar 20 2021 daviddavid <daviddavid> 2.9.0-2.mga9
+ Revision: 1705222
- rebuild for armv7

* Wed Mar 17 2021 daviddavid <daviddavid> 2.9.0-1.mga9
+ Revision: 1704031
- new version: 2.9.0

* Wed Mar 17 2021 daviddavid <daviddavid> 2.8.0-2.mga9
+ Revision: 1703990
- rebuild for python 3.9

* Tue Mar 02 2021 daviddavid <daviddavid> 2.8.0-1.mga9
+ Revision: 1695766
- new version: 2.8.0
- new version: 2.7.0

* Fri Feb 26 2021 daviddavid <daviddavid> 2.5.2-1.mga9
+ Revision: 1691691
- new version: 2.5.2

* Mon Jan 25 2021 daviddavid <daviddavid> 2.4.0-1.mga8
+ Revision: 1673248
- new version: 2.4.0 (fixes build against qpdf 10.1.0)

* Wed Dec 30 2020 daviddavid <daviddavid> 2.2.4-1.mga8
+ Revision: 1665554
- new version: 2.2.4

* Tue Dec 29 2020 daviddavid <daviddavid> 2.2.3-1.mga8
+ Revision: 1664705
- new version: 2.2.3

* Fri Dec 25 2020 daviddavid <daviddavid> 2.2.2-1.mga8
+ Revision: 1663649
- new version: 2.2.2

* Wed Oct 28 2020 daviddavid <daviddavid> 1.19.3-2.mga8
+ Revision: 1640098
- relax pytest dependency
- relax pytest-xdist dependency

* Fri Sep 11 2020 daviddavid <daviddavid> 1.19.3-1.mga8
+ Revision: 1624666
- new version: 1.19.3

* Mon Sep 07 2020 daviddavid <daviddavid> 1.19.1-1.mga8
+ Revision: 1623302
- new version: 1.19.1

* Tue Aug 25 2020 daviddavid <daviddavid> 1.19.0-1.mga8
+ Revision: 1618833
- new version: 1.19.0

* Tue Aug 18 2020 daviddavid <daviddavid> 1.18.0-1.mga8
+ Revision: 1614725
- new version: 1.18.0

* Sun Aug 02 2020 daviddavid <daviddavid> 1.17.3-1.mga8
+ Revision: 1610484
- new version: 1.17.3

* Fri Jul 17 2020 daviddavid <daviddavid> 1.17.2-1.mga8
+ Revision: 1606709
- new version: 1.17.2

* Tue Jul 14 2020 daviddavid <daviddavid> 1.17.1-1.mga8
+ Revision: 1605895
- new version: 1.17.1

* Sat Jul 04 2020 daviddavid <daviddavid> 1.16.1-1.mga8
+ Revision: 1601803
- new version: 1.16.1

* Sun Jun 21 2020 daviddavid <daviddavid> 1.15.1-1.mga8
+ Revision: 1598275
- new version: 1.15.1

* Sun Jun 21 2020 daviddavid <daviddavid> 1.15.0-1.mga8
+ Revision: 1598248
- new version: 1.15.0

* Mon Jun 01 2020 daviddavid <daviddavid> 1.14.0-2.mga8
+ Revision: 1589443
- enable testsuite

* Mon Jun 01 2020 daviddavid <daviddavid> 1.14.0-1.mga8
+ Revision: 1589351
- new version: 1.14.0

* Mon May 18 2020 daviddavid <daviddavid> 1.13.0-1.mga8
+ Revision: 1585989
- new version: 1.13.0

* Sun May 17 2020 daviddavid <daviddavid> 1.12.0-1.mga8
+ Revision: 1585457
- new version: 1.12.0

* Wed May 06 2020 daviddavid <daviddavid> 1.11.2-1.mga8
+ Revision: 1580730
- new version: 1.11.2

* Fri Apr 17 2020 daviddavid <daviddavid> 1.11.1-1.mga8
+ Revision: 1567977
- new version: 1.11.1

* Tue Apr 14 2020 tv <tv> 1.11.0-2.mga8
+ Revision: 1567334
- rebuild for new qpdf

* Mon Apr 13 2020 daviddavid <daviddavid> 1.11.0-1.mga8
+ Revision: 1567053
- new version: 1.11.0

* Thu Apr 02 2020 daviddavid <daviddavid> 1.10.4-1.mga8
+ Revision: 1563979
- new version: 1.10.4

* Thu Mar 19 2020 daviddavid <daviddavid> 1.10.3-1.mga8
+ Revision: 1557911
- new version: 1.10.3

* Sat Feb 29 2020 daviddavid <daviddavid> 1.10.2-1.mga8
+ Revision: 1552191
- new version: 1.10.2

* Fri Feb 21 2020 umeabot <umeabot> 1.10.1-2.mga8
+ Revision: 1547791
- Mageia 8 Mass Rebuild

* Tue Feb 18 2020 daviddavid <daviddavid> 1.10.1-1.mga8
+ Revision: 1541910
- new version: 1.10.1

* Mon Feb 10 2020 daviddavid <daviddavid> 1.10.0-1.mga8
+ Revision: 1488390
- disable test suite for now
- initial package python-pikepdf (needed for pdfarranger)

